# Select device to change

- ‹ 2000
- January 1

MockedCsrfTokenNode
Action:
0 of 1 selected

| Uuid | Name | Location count | Last Location | Create date | Last update
--- | --- | --- | --- | --- | --- | ---
| 00000000-0000-0000-0000-000000000001 | Smartphone John | 1 | Jan. 1, 2000, 1:02 a.m. | Jan. 1, 2000, 1:01 a.m. | Jan. 1, 2000, 1:03 a.m.

1 device

## Filter

### By name

- All
- Smartphone John